@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1982-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2022 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -14,6 +14,7 @@
 *                  Martijn Dekker <martijn@inlv.org>                   *
 *            Johnothan King <johnothanking@protonmail.com>             *
 *                      Phi <phi.debian@gmail.com>                      *
+*               K. Eugene Carlson <kvngncrlsn@gmail.com>               *
 *                                                                      *
 ***********************************************************************/
 /*
@@ -93,14 +94,14 @@ static void		applyopts(Shopt_t);
 
 void *sh_argopen(void)
 {
-	return(sh_newof(0,Arg_t,1,0));
+	return sh_newof(0,Arg_t,1,0);
 }
 
 static int infof(Opt_t* op, Sfio_t* sp, const char* s, Optdisc_t* dp)
 {
 	if(*s!=':')
 		sfputr(sp,sh_set,-1);
-	return(1);
+	return 1;
 }
 
 /*
@@ -109,16 +110,16 @@ static int infof(Opt_t* op, Sfio_t* sp, const char* s, Optdisc_t* dp)
  *  The -o option is used to set option by name
  *  This routine returns the number of non-option arguments
  */
-int sh_argopts(int argc,register char *argv[])
+int sh_argopts(int argc,char *argv[])
 {
-	register int	n,o;
-	register Arg_t	*ap = (Arg_t*)(sh.arg_context);
+	int		n,o;
+	Arg_t		*ap = (Arg_t*)(sh.arg_context);
 #if SHOPT_KIA
 	Lex_t		*lp = (Lex_t*)(sh.lex_context);
 #endif
 	Shopt_t		newflags;
 	int		defaultflag=0, setflag=0, action=0, trace=(int)sh_isoption(SH_XTRACE);
-	Namval_t *np = NIL(Namval_t*);
+	Namval_t *np = NULL;
 	const char *cp;
 	int verbose,f;
 	Optdisc_t disc;
@@ -167,7 +168,7 @@ int sh_argopts(int argc,register char *argv[])
 			break;
 		    case -6:	/* --default */
 			{
-				register const Shtable_t *tp;
+				const Shtable_t *tp;
 				for(tp=shtab_options; o = tp->sh_number; tp++)
 				{
 					if(!(o&SH_COMMANDLINE) && (o&=0xff)!=SH_RESTRICTED && is_option(&newflags,o))
@@ -226,7 +227,7 @@ int sh_argopts(int argc,register char *argv[])
 			continue;
 		    case '?':
 			errormsg(SH_DICT,ERROR_usage(0), "%s", opt_info.arg);
-			return(-1);
+			return -1;
 		}
 		if(f)
 		{
@@ -279,7 +280,7 @@ int sh_argopts(int argc,register char *argv[])
 	}
 	if(error_info.errors)
 	{
-		errormsg(SH_DICT,ERROR_usage(2),"%s",optusage(NIL(char*)));
+		errormsg(SH_DICT,ERROR_usage(2),"%s",optusage(NULL));
 		UNREACHABLE();
 	}
 	/* check for '-' or '+' argument */
@@ -316,7 +317,7 @@ int sh_argopts(int argc,register char *argv[])
 		if(!(sh.comdiv = *argv++))
 		{
 			errormsg(SH_DICT,2,e_cneedsarg);
-			errormsg(SH_DICT,ERROR_usage(2),optusage(NIL(char*)));
+			errormsg(SH_DICT,ERROR_usage(2),optusage(NULL));
 			UNREACHABLE();
 		}
 		argc--;
@@ -331,7 +332,7 @@ int sh_argopts(int argc,register char *argv[])
 			errormsg(SH_DICT,ERROR_usage(2),"-R requires scriptname");
 			UNREACHABLE();
 		}
-		if(!(lp->kiafile=sfopen(NIL(Sfio_t*),ap->kiafile,"w+")))
+		if(!(lp->kiafile=sfopen(NULL,ap->kiafile,"w+")))
 		{
 			errormsg(SH_DICT,ERROR_system(3),e_create,ap->kiafile);
 			UNREACHABLE();
@@ -353,7 +354,7 @@ int sh_argopts(int argc,register char *argv[])
 		ap->kiafile = 0;
 	}
 #endif /* SHOPT_KIA */
-	return(argc);
+	return argc;
 }
 
 /* apply new options */
@@ -396,9 +397,9 @@ static void applyopts(Shopt_t newflags)
  */
 char *sh_argdolminus(void* context)
 {
-	register Arg_t *ap = (Arg_t*)context;
-	register const char *cp=optksh;
-	register char *flagp=ap->flagadr;
+	Arg_t *ap = (Arg_t*)context;
+	const char *cp=optksh;
+	char *flagp=ap->flagadr;
 	while(cp< &optksh[NUM_OPTS])
 	{
 		int n = flagval[cp-optksh];
@@ -407,7 +408,7 @@ char *sh_argdolminus(void* context)
 		cp++;
 	}
 	*flagp = 0;
-	return(ap->flagadr);
+	return ap->flagadr;
 }
 
 /*
@@ -433,9 +434,9 @@ static void argset(Arg_t *ap,char *argv[])
  */
 struct dolnod *sh_argfree(struct dolnod *blk,int flag)
 {
-	register struct dolnod*	argr=blk;
-	register struct dolnod*	argblk;
-	register Arg_t *ap = (Arg_t*)sh.arg_context;
+	struct dolnod*	argr=blk;
+	struct dolnod*	argblk;
+	Arg_t *ap = (Arg_t*)sh.arg_context;
 	if(argblk=argr)
 	{
 		if((--argblk->dolrefcnt)==0)
@@ -454,27 +455,27 @@ struct dolnod *sh_argfree(struct dolnod *blk,int flag)
 						if(argr->dolnxt==argblk)
 							break;
 					if(!argr)
-						return(NIL(struct dolnod*));
+						return NULL;
 					argr->dolnxt = argblk->dolnxt;
 					argr = argblk->dolnxt;
 				}
-				free((void*)argblk);
+				free(argblk);
 			}
 		}
 	}
-	return(argr);
+	return argr;
 }
 
 /*
  * grab space for arglist and copy args
  * The strings are copied after the argument vector
  */
-struct dolnod *sh_argcreate(register char *argv[])
+struct dolnod *sh_argcreate(char *argv[])
 {
-	register struct dolnod *dp;
-	register char **pp=argv, *sp;
-	register int 	n;
-	register size_t	size=0;
+	struct dolnod *dp;
+	char **pp=argv, *sp;
+	int 	n;
+	size_t	size=0;
 	/* count args and number of bytes of arglist */
 	while(sp= *pp++)
 		size += strlen(sp);
@@ -490,8 +491,8 @@ struct dolnod *sh_argcreate(register char *argv[])
 		*pp++ = sp;
 		sp = strcopy(sp, *argv++) + 1;
 	}
-	*pp = NIL(char*);
-	return(dp);
+	*pp = NULL;
+	return dp;
 }
 
 /*
@@ -499,13 +500,13 @@ struct dolnod *sh_argcreate(register char *argv[])
  */
 struct dolnod *sh_argnew(char *argi[], struct dolnod **savargfor)
 {
-	register Arg_t *ap = (Arg_t*)sh.arg_context;
-	register struct dolnod *olddolh = ap->dolh;
+	Arg_t *ap = (Arg_t*)sh.arg_context;
+	struct dolnod *olddolh = ap->dolh;
 	*savargfor = ap->argfor;
 	ap->dolh = 0;
 	ap->argfor = 0;
 	argset(ap,argi);
-	return(olddolh);
+	return olddolh;
 }
 
 /*
@@ -513,7 +514,7 @@ struct dolnod *sh_argnew(char *argi[], struct dolnod **savargfor)
  */
 void sh_argreset(struct dolnod *blk, struct dolnod *afor)
 {
-	register Arg_t *ap = (Arg_t*)sh.arg_context;
+	Arg_t *ap = (Arg_t*)sh.arg_context;
 	while(ap->argfor=sh_argfree(ap->argfor,0));
 	ap->argfor = afor;
 	if(ap->dolh = blk)
@@ -528,11 +529,11 @@ void sh_argreset(struct dolnod *blk, struct dolnod *afor)
  */
 struct dolnod *sh_arguse(void)
 {
-	register struct dolnod *dh;
-	register Arg_t *ap = (Arg_t*)sh.arg_context;
+	struct dolnod *dh;
+	Arg_t *ap = (Arg_t*)sh.arg_context;
 	if(dh=ap->dolh)
 		dh->dolrefcnt++;
-	return(dh);
+	return dh;
 }
 
 /*
@@ -540,9 +541,9 @@ struct dolnod *sh_arguse(void)
  *  if mode is inclusive or of PRINT_*
  *  if <mask> is set, only options with this mask value are displayed
  */
-void sh_printopts(Shopt_t oflags,register int mode, Shopt_t *mask)
+void sh_printopts(Shopt_t oflags,int mode, Shopt_t *mask)
 {
-	register const Shtable_t *tp;
+	const Shtable_t *tp;
 	const char *name;
 	int on;
 	int value;
@@ -595,7 +596,7 @@ void sh_printopts(Shopt_t oflags,register int mode, Shopt_t *mask)
 			sfputc(sfstdout,'\n');
 		return;
 	}
-#if SHOPT_VSH && SHOPT_RAWONLY
+#if SHOPT_VSH
 	on_option(&oflags,SH_VIRAW);
 #endif
 	if(!(mode&(PRINT_ALL|PRINT_VERBOSE))) /* only print set options */
@@ -631,23 +632,23 @@ void sh_printopts(Shopt_t oflags,register int mode, Shopt_t *mask)
  */
 char **sh_argbuild(int *nargs, const struct comnod *comptr,int flag)
 {
-	register struct argnod	*argp=0;
+	struct argnod *argp=0;
 	struct argnod *arghead=0;
 	sh.xargmin = 0;
 	{
-		register const struct comnod	*ac = comptr;
-		register int n;
+		const struct comnod *ac = comptr;
+		int n;
 		/* see if the arguments have already been expanded */
 		if(!ac->comarg)
 		{
 			*nargs = 0;
-			return(&null);
+			return &null;
 		}
 		else if(!(ac->comtyp&COMSCAN))
 		{
-			register struct dolnod *ap = (struct dolnod*)ac->comarg;
+			struct dolnod *ap = (struct dolnod*)ac->comarg;
 			*nargs = ap->dolnum;
-			return(ap->dolval+ap->dolbot);
+			return ap->dolval+ap->dolbot;
 		}
 		*nargs = 0;
 		if(ac)
@@ -669,9 +670,9 @@ char **sh_argbuild(int *nargs, const struct comnod *comptr,int flag)
 		}
 	}
 	{
-		register char	**comargn;
-		register int	argn, argi;
-		register char	**comargm;
+		char	**comargn;
+		int	argn, argi;
+		char	**comargm;
 		/*
 		 * When argbuild is aborted (longjmp) from a discipline function (unset
 		 * var access in discipline), we count an arg that is unset at the end of
@@ -682,12 +683,12 @@ char **sh_argbuild(int *nargs, const struct comnod *comptr,int flag)
 		argn = *nargs + 1;	/* allow room to prepend args */
 		comargn=(char**)stkalloc(sh.stk,(unsigned)(argn+1)*sizeof(char*));
 		comargm = comargn += argn;
-		*comargn = NIL(char*);
+		*comargn = NULL;
 		if(!argp)
 		{
 			/* reserve an extra null pointer */
 			*--comargn = 0;
-			return(comargn);
+			return comargn;
 		}
 		argi = 0;
 		while(argp)
@@ -707,7 +708,7 @@ char **sh_argbuild(int *nargs, const struct comnod *comptr,int flag)
 		}
 		sh.last_table = 0;
 		*nargs=argi;
-		return(comargn);
+		return comargn;
 	}
 }
 
@@ -718,7 +719,7 @@ char **sh_argbuild(int *nargs, const struct comnod *comptr,int flag)
 struct argnod *sh_argprocsub(struct argnod *argp)
 {
 	/* argument of the form <(cmd) or >(cmd) */
-	register struct argnod *ap;
+	struct argnod *ap;
 	int fd, pv[3];
 	int savestates = sh_getstate();
 	char savejobcontrol = job.jobcontrol;
@@ -771,7 +772,7 @@ struct argnod *sh_argprocsub(struct argnod *argp)
 	sh_setstate(savestates);
 #if SHOPT_DEVFD
 	sh_close(pv[1-fd]);
-	sh_iosave(-pv[fd], sh.topfd, (char*)0);
+	sh_iosave(-pv[fd], sh.topfd, NULL);
 #else
 	/* remember the FIFO for cleanup in case the command never opens it (see fifo_cleanup(), xec.c) */
 	if(!sh.fifo_tree)
@@ -780,13 +781,13 @@ struct argnod *sh_argprocsub(struct argnod *argp)
 	free(sh.fifo);
 	sh.fifo = 0;
 #endif /* SHOPT_DEVFD */
-	return(ap);
+	return ap;
 }
 
 /* Argument expansion */
-static int arg_expand(register struct argnod *argp, struct argnod **argchain,int flag)
+static int arg_expand(struct argnod *argp, struct argnod **argchain,int flag)
 {
-	register int count = 0;
+	int count = 0;
 	argp->argflag &= ~ARG_MAKE;
 	if(*argp->argval==0 && (argp->argflag&ARG_EXP))
 	{
@@ -824,5 +825,5 @@ static int arg_expand(register struct argnod *argp, struct argnod **argchain,int
 		argp->argflag |= ARG_MAKE;
 		count++;
 	}
-	return(count);
+	return count;
 }
